DefaultHashTable

Struct DefaultHashTable 

pub struct DefaultHashTable<TKey, TValue, TAllocator>
where TKey: Eq + Hash, TAllocator: Allocator,
{ /* private fields */ }
Represents the default hash table.

Notes

At the moment it uses the AbseilHashTable as the underlying implementation. This can change in the future though.

Implementations

Source

impl<TKey, TValue, TAllocator> DefaultHashTable<TKey, TValue, TAllocator>
where TKey: Eq + Hash, TAllocator: Allocator,

pub fn new() -> Self
where TAllocator: Default,

Creates a new, empty DefaultHashTable with the default allocator.

pub fn with_allocator(allocator: TAllocator) -> Self

Creates a new, empty DefaultHashTable with the specified allocator.

pub fn with_capacity(capacity: Length) -> Result<Self, HashTableError>
where TAllocator: Default,

Creates a new DefaultHashTable with the specified capacity and the default allocator.

This likely will (over)allocate memory.

Errors

See HashTableError for details.

pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, HashTableError>

Creates a new DefaultHashTable with the specified capacity and the specified allocator.

This likely will (over)allocate memory.

Errors

See HashTableError for details.