#[repr(u8)]pub enum DefaultHashTableError {
AllocationError = 0,
TableTooBigError = 1,
}Expand description
Represents a general possible error for the default hash table.
Variants
AllocationError = 0
The underlying allocator returned an error, likely due to out of memory.
TableTooBigError = 1
The table is too big to be allocated.