pub struct DefaultHashTable<TKey, TValue, TAllocator>{ /* private fields */ }Expand description
Represents the default hash table.
Notes
At the moment it uses BytellHashTable as the underlying implementation.
This can change in the future though.
Implementations
Sourceimpl<TKey, TValue, TAllocator> DefaultHashTable<TKey, TValue, TAllocator>
impl<TKey, TValue, TAllocator> DefaultHashTable<TKey, TValue, TAllocator>
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new, empty DefaultHashTable with the default allocator.
Sourcepub fn with_allocator(allocator: TAllocator) -> Self
pub fn with_allocator(allocator: TAllocator) -> Self
Creates a new, empty DefaultHashTable with the specified allocator.
Sourcepub fn with_capacity(capacity: Length) -> Result<Self, DefaultHashTableError>
pub fn with_capacity(capacity: Length) -> Result<Self, DefaultHashTableError>
Creates a new DefaultHashTable with the specified capacity and the default allocator.
This likely will (over)allocate memory.
Errors
See DefaultHashTableError for details.
Sourcepub fn with_capacity_and_allocator(
capacity: Length,
allocator: TAllocator,
) -> Result<Self, DefaultHashTableError>
pub fn with_capacity_and_allocator( capacity: Length, allocator: TAllocator, ) -> Result<Self, DefaultHashTableError>
Creates a new DefaultHashTable with the specified capacity and the specified allocator.
This likely will (over)allocate memory.
Errors
See DefaultHashTableError for details.